pip2nix
=======

.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   getting_started
   configuration
   examples
   tips

.. toctree::
   :maxdepth: 2
   :caption: Developer Documentation

   HACKING

.. toctree::
   :maxdepth: 1
   :caption: History

   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
